@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -35,6 +35,7 @@
 static int hsomodem_init(void)
 {
 	hso_gprs_context_init();
+	hso_radio_settings_init();
 
 	return 0;
 }
@@ -42,6 +43,7 @@ static int hsomodem_init(void)
 static void hsomodem_exit(void)
 {
 	hso_gprs_context_exit();
+	hso_radio_settings_exit();
 }
 
 OFONO_PLUGIN_DEFINE(hsomodem, "HSO modem driver", VERSION,
