@@ -77,6 +77,7 @@ enum ofono_sim_state {
 	OFONO_SIM_STATE_INSERTED,
 	OFONO_SIM_STATE_LOCKED_OUT,
 	OFONO_SIM_STATE_READY,
+	OFONO_SIM_STATE_RESETTING,
 };
 
 typedef void (*ofono_sim_file_info_cb_t)(const struct ofono_error *error,
@@ -125,24 +126,31 @@ struct ofono_sim_driver {
 	int (*probe)(struct ofono_sim *sim, unsigned int vendor, void *data);
 	void (*remove)(struct ofono_sim *sim);
 	void (*read_file_info)(struct ofono_sim *sim, int fileid,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_file_info_cb_t cb, void *data);
 	void (*read_file_transparent)(struct ofono_sim *sim, int fileid,
 			int start, int length,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_read_cb_t cb, void *data);
 	void (*read_file_linear)(struct ofono_sim *sim, int fileid,
 			int record, int length,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_read_cb_t cb, void *data);
 	void (*read_file_cyclic)(struct ofono_sim *sim, int fileid,
 			int record, int length,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_read_cb_t cb, void *data);
 	void (*write_file_transparent)(struct ofono_sim *sim, int fileid,
 			int start, int length, const unsigned char *value,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_write_cb_t cb, void *data);
 	void (*write_file_linear)(struct ofono_sim *sim, int fileid,
 			int record, int length, const unsigned char *value,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_write_cb_t cb, void *data);
 	void (*write_file_cyclic)(struct ofono_sim *sim, int fileid,
 			int length, const unsigned char *value,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_write_cb_t cb, void *data);
 	void (*read_imsi)(struct ofono_sim *sim,
 			ofono_sim_imsi_cb_t cb, void *data);
@@ -183,11 +191,14 @@ void *ofono_sim_get_data(struct ofono_sim *sim);
 const char *ofono_sim_get_imsi(struct ofono_sim *sim);
 const char *ofono_sim_get_mcc(struct ofono_sim *sim);
 const char *ofono_sim_get_mnc(struct ofono_sim *sim);
+const char *ofono_sim_get_spn(struct ofono_sim *sim);
 enum ofono_sim_phase ofono_sim_get_phase(struct ofono_sim *sim);
 
 enum ofono_sim_cphs_phase ofono_sim_get_cphs_phase(struct ofono_sim *sim);
 const unsigned char *ofono_sim_get_cphs_service_table(struct ofono_sim *sim);
 
+enum ofono_sim_password_type ofono_sim_get_password_type(struct ofono_sim *sim);
+
 unsigned int ofono_sim_add_state_watch(struct ofono_sim *sim,
 					ofono_sim_state_event_cb_t cb,
 					void *data, ofono_destroy_func destroy);
@@ -196,6 +207,14 @@ void ofono_sim_remove_state_watch(struct ofono_sim *sim, unsigned int id);
 
 enum ofono_sim_state ofono_sim_get_state(struct ofono_sim *sim);
 
+typedef void (*ofono_sim_spn_cb_t)(const char *spn, const char *dc, void *data);
+
+ofono_bool_t ofono_sim_add_spn_watch(struct ofono_sim *sim, unsigned int *id,
+					ofono_sim_spn_cb_t cb, void *data,
+					ofono_destroy_func destroy);
+
+ofono_bool_t ofono_sim_remove_spn_watch(struct ofono_sim *sim, unsigned int *id);
+
 void ofono_sim_inserted_notify(struct ofono_sim *sim, ofono_bool_t inserted);
 
 struct ofono_sim_context *ofono_sim_context_create(struct ofono_sim *sim);
@@ -219,6 +238,7 @@ int ofono_sim_write(struct ofono_sim_context *context, int id,
 
 int ofono_sim_read_bytes(struct ofono_sim_context *context, int id,
 			unsigned short offset, unsigned short num_bytes,
+			const unsigned char *path, unsigned int path_len,
 			ofono_sim_file_read_cb_t cb, void *data);
 
 unsigned int ofono_sim_add_file_watch(struct ofono_sim_context *context,
