@@ -30,6 +30,9 @@ void __ofono_exit(void);
 int __ofono_manager_init(void);
 void __ofono_manager_cleanup(void);
 
+int __ofono_handsfree_audio_manager_init(void);
+void __ofono_handsfree_audio_manager_cleanup(void);
+
 void __ofono_modem_shutdown(void);
 
 #include <ofono/log.h>
@@ -65,6 +68,8 @@ DBusMessage *__ofono_error_access_denied(DBusMessage *msg);
 DBusMessage *__ofono_error_emergency_active(DBusMessage *msg);
 DBusMessage *__ofono_error_incorrect_password(DBusMessage *msg);
 DBusMessage *__ofono_error_not_allowed(DBusMessage *msg);
+DBusMessage *__ofono_error_not_recognized(DBusMessage *msg);
+DBusMessage *__ofono_error_network_terminated(DBusMessage *msg);
 
 DBusMessage *__ofono_error_from_error(const struct ofono_error *error,
 						DBusMessage *msg);
@@ -146,6 +151,7 @@ enum ofono_atom_type {
 	OFONO_ATOM_TYPE_CDMA_SMS,
 	OFONO_ATOM_TYPE_CDMA_NETREG,
 	OFONO_ATOM_TYPE_HANDSFREE,
+	OFONO_ATOM_TYPE_SIRI,
 };
 
 enum ofono_atom_watch_condition {
@@ -187,10 +193,10 @@ struct ofono_modem *__ofono_atom_get_modem(struct ofono_atom *atom);
 
 #define __ofono_atom_find(enum_type, modem)			\
 ({								\
-	struct ofono_atom *atom =				\
+	struct ofono_atom *tmp_atom =				\
 		__ofono_modem_find_atom(modem, enum_type);	\
 								\
-	atom ? __ofono_atom_get_data(atom) : NULL;		\
+	tmp_atom ? __ofono_atom_get_data(tmp_atom) : NULL;	\
 })
 
 void __ofono_atom_register(struct ofono_atom *atom,
